"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const transform_1 = require("./transform");
const attribute_1 = require("./attribute");
const parser_1 = require("html-validate/build/parser");
const config_1 = require("html-validate/build/config");
const dom_1 = require("html-validate/build/dom");
const test_utils_1 = require("html-validate/build/transform/test-utils");
test("should extract template from components", () => {
    const result = test_utils_1.transformFile(transform_1.angularTransformJS, "./test/component.js");
    expect(result).toHaveLength(1);
    expect(result[0]).toMatchInlineSnapshot(`
		Object {
		  "column": 12,
		  "data": "<p>foo</i>",
		  "filename": "./test/component.js",
		  "hooks": Object {
		    "processAttribute": [Function],
		    "processElement": [Function],
		  },
		  "line": 2,
		  "offset": 42,
		}
	`);
});
test("should extract templates from routes", () => {
    const result = test_utils_1.transformFile(transform_1.angularTransformJS, "./test/route.js");
    expect(result).toHaveLength(3);
    expect(result[0]).toMatchInlineSnapshot(`
		Object {
		  "column": 31,
		  "data": "<p>foo</i>",
		  "filename": "./test/route.js",
		  "hooks": Object {
		    "processAttribute": [Function],
		    "processElement": [Function],
		  },
		  "line": 3,
		  "offset": 93,
		}
	`);
    expect(result[1]).toMatchInlineSnapshot(`
		Object {
		  "column": 14,
		  "data": "
						<button>
							bar
						</button>
					",
		  "filename": "./test/route.js",
		  "hooks": Object {
		    "processAttribute": [Function],
		    "processElement": [Function],
		  },
		  "line": 5,
		  "offset": 137,
		}
	`);
    expect(result[2]).toMatchInlineSnapshot(`
		Object {
		  "column": 14,
		  "data": "<button type=\\"{{valid}}\\"></button>",
		  "filename": "./test/route.js",
		  "hooks": Object {
		    "processAttribute": [Function],
		    "processElement": [Function],
		  },
		  "line": 12,
		  "offset": 226,
		}
	`);
});
test("should extract template from html file", () => {
    const result = test_utils_1.transformFile(transform_1.angularTransformHTML, "./test/template.html");
    expect(result).toHaveLength(1);
    expect(result[0]).toMatchInlineSnapshot(`
		Object {
		  "column": 1,
		  "data": "<div>
			<button></button>
			<button type=\\"invalid\\"></button>
			<button type=\\"{{ valid }}\\"></button>
			<button ng-attr-type=\\"valid\\"></button>
		</div>

		<!-- should detect duplicated ng-class but not duplicate class + ng-class -->
		<p class=\\"foo\\" ng-class=\\"bar\\"></p>
		<p ng-class=\\"foo\\" ng-class=\\"bar\\"></p>

		<!-- should detect ng-bind and friends as having textual content -->
		<h1></h1>
		<h2 ng-bind=\\"foo\\"></h2>
		<h3 ng-bind-html=\\"bar\\"></h3>
		<h3 ng-bind-template=\\"baz\\"></h3>
		<h4 translate=\\"KEY\\"></h4>

		<h1 ng-transclude></h1>
		<h1><ng-transclude></ng-transclude></h1>
		<h1 ng-pluralize></h1>
		<h1><ng-pluralize></ng-pluralize></h1>
		",
		  "filename": "./test/template.html",
		  "hooks": Object {
		    "processAttribute": [Function],
		    "processElement": [Function],
		  },
		  "line": 1,
		  "offset": 0,
		}
	`);
});
test("querySelector should find class with ng-class present", () => {
    const parser = new parser_1.Parser(config_1.Config.empty());
    const source = {
        data: '<p class="foo" ng-class="bar"></p>',
        filename: "inline",
        line: 1,
        column: 1,
        offset: 0,
        hooks: {
            processAttribute: attribute_1.processAttribute,
        },
    };
    const doc = parser.parseHtml(source);
    const node = doc.querySelector(".foo");
    expect(node).toBeInstanceOf(dom_1.HtmlElement);
    expect(Array.from(node.classList)).toEqual(["foo"]);
    expect(node.getAttribute("class", true)).toEqual([
        expect.objectContaining({
            key: "class",
            value: "foo",
        }),
        expect.objectContaining({
            key: "class",
            value: expect.any(dom_1.DynamicValue),
            originalAttribute: "ng-class",
        }),
    ]);
});
